{% if tabs_list or inlines_list or datasets_list %}
    <div id="tabs-wrapper" class="flex items-start flex-col mb-4 md:flex-row md:items-center">
        {% include "unfold/helpers/tab_items.html" %}
    </div>
{% endif %}
