{% extends "admin/base_site.html" %}
{% load admin_urls i18n static %}

{% block extrastyle %}{{ block.super }}{% endblock %}

{% block content %}
    <div id="content-main">
        {% translate 'Your password was changed.' as message %}
        {% include "unfold/helpers/messages/success.html" with message=message %}
    </div>
{% endblock %}
